@@ -1,6 +1,6 @@
 package Algorithm::Easing::Bounce;
 
-use Moose;
+use Moo;
 
 use Math::Trig qw(:pi);
 
@@ -69,6 +69,9 @@ Algorithm::Easing::Bounce - Calculate eased translations between two positive wh
 =cut
 
 =head1 SYNOPSIS
+
+        ## with mediator
+
         use Algorithm::Easing;
         use Algorithm::Easing::Bounce;
 
