@@ -1,6 +1,6 @@
 package Algorithm::Easing::Circular;
 
-use Moose;
+use Moo;
 
 use Math::Complex;
 use Math::Trig qw(:pi);
@@ -59,6 +59,8 @@ Algorithm::Easing::Circular - Calculate eased translations between two positive
 
 =head1 SYNOPSIS
 
+        ## with mediator
+
         use Algorithm::Easing;
         use Algorithm::Easing::Circular;
 
