@@ -1,6 +1,6 @@
 package Algorithm::Easing::Exponential;
 
-use Moose;
+use Moo;
 
 use Math::Trig qw(:pi);
 
@@ -66,6 +66,8 @@ Algorithm::Easing::Exponential - Calculate eased translations between two positi
 
 =head1 SYNOPSIS
 
+        ## with mediator
+
         use Algorithm::Easing;
         use Algorithm::Easing::Exponential;
 
