@@ -1,6 +1,6 @@
 package Algorithm::Easing::Quadratic;
 
-use Moose;
+use Moo;
 
 use Math::Trig qw(:pi);
 
@@ -57,6 +57,8 @@ Algorithm::Easing::Quadratic - Calculate eased translations between two positive
 
 =head1 SYNOPSIS
 
+        ## with mediator
+
         use Algorithm::Easing;
         use Algorithm::Easing::Quadratic;
 
